Class: DIDWW::ComplexObject::AuthenticationMethod::IpOnly
- Inherits:
-
Base
- Object
- ComplexObject::Base
- Base
- DIDWW::ComplexObject::AuthenticationMethod::IpOnly
- Defined in:
- lib/didww/complex_objects/authentication_methods/ip_only.rb
Overview
IpOnly is a read-only authentication method. It can only be configured manually by DIDWW staff upon request and cannot be set via the API on create or update. Trunks with ip_only authentication can still be read and their non-auth attributes updated via the API.
Class Method Summary collapse
Class Method Details
.type ⇒ Object
12 13 14 |
# File 'lib/didww/complex_objects/authentication_methods/ip_only.rb', line 12 def self.type 'ip_only' end |