Class: DIDWW::ComplexObject::AuthenticationMethod::IpOnly

Inherits:
Base
  • Object
show all
Defined in:
lib/didww/complex_objects/authentication_methods/ip_only.rb

Overview

IpOnly is a read-only authentication method. It can only be configured manually by DIDWW staff upon request and cannot be set via the API on create or update. Trunks with ip_only authentication can still be read and their non-auth attributes updated via the API.

Class Method Summary collapse

Methods inherited from Base

#[], #[]=, #as_json, #as_json_api, #attributes, cast, #initialize, property, schema, #type

Constructor Details

This class inherits a constructor from DIDWW::ComplexObject::Base

Class Method Details

.typeObject



12
13
14
# File 'lib/didww/complex_objects/authentication_methods/ip_only.rb', line 12

def self.type
  'ip_only'
end